summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/t6721a.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/t6721a.cpp')
-rw-r--r--src/devices/sound/t6721a.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/devices/sound/t6721a.cpp b/src/devices/sound/t6721a.cpp
index 7c0c07544e0..2c29e31dc62 100644
--- a/src/devices/sound/t6721a.cpp
+++ b/src/devices/sound/t6721a.cpp
@@ -56,17 +56,18 @@ void t6721a_device::device_start()
m_write_apd.resolve_safe();
// create sound stream
- m_stream = stream_alloc_legacy(0, 1, machine().sample_rate());
+ m_stream = stream_alloc(0, 1, machine().sample_rate());
}
//-------------------------------------------------
// sound_stream_update_legacy - handle update requests for
// our sound stream
//-------------------------------------------------
-void t6721a_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
+void t6721a_device::sound_stream_update(sound_stream &stream, std::vector<read_stream_view> const &inputs, std::vector<write_stream_view> &outputs)
{
+ outputs[0].fill(0);
}
@@ -56,17 +56,18 @@ void t6721a_device::device_start()
}
//-------------------------------------------------
-// sound_stream_update_legacy - handle update requests for
+// sound_stream_update - handle update requests for
// our sound stream
//-------------------------------------------------